eq_clean_data: Formatting the imported NOAA Database into a usable format.

Description Usage Value Note Examples

Description

This function modfies the original raw data set from the NOAA Signficant Earthquake Database by formatting key columns to be used in exploratory analysis.

This function modfies the original raw data set from the NOAA Signficant Earthquake Database by formatting key columns to be used in exploratory analysis.

Usage

1
2
3

Value

A formatted dataframe is returned with a location name that has a properly formatted for graphing, latitude and longditude values are numeric and dates are formatted approriately.

A formatted dataframe is returned with a location name that has a properly formatted for graphing, latitude and longditude values are numeric and dates are formatted approriately.

Note

This function modifies key fields of the imported NOAA earth quake data set for exploratory analysis. It will also return a dataframe with a properly formatted date field called 'datevalue.'

This function modifies key fields of the imported NOAA earth quake data set for exploratory analysis. It will also return a dataframe with a properly formatted date field called 'datevalue.'

Examples

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
## Not run: 

# Use the "results" dataframe name from the import routine.
# Reformat select fields for graphical analysis.  
# Assign the newly formatted dataframe to a user chosen name.

library(dplyr)
any_name_df<-eq_clean_data(results)


## End(Not run) 


## Not run: 

# Use the "results" dataframe name from the import routine.
# Reformat select fields for graphical analysis.  
# Assign the newly formatted dataframe to a user chosen name.

library(dplyr)
any_name_df<-eq_clean_data(results)


## End(Not run) 

cowboy2718/QuakeExplorer documentation built on May 26, 2019, 4:41 p.m.